==> haskell-tasty-quickcheck-0.10.3-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.10.3
visibility:           public
id:                   tasty-quickcheck-0.10.3-CkXnrqaZ4euQzG8XGZIrI
key:                  tasty-quickcheck-0.10.3-CkXnrqaZ4euQzG8XGZIrI
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  8b4cc4827310a12b32b2e9cf6cd1f343
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.3-CkXnrqaZ4euQzG8XGZIrI
depends:
    QuickCheck-2.15.0.1-3THVvT7MDMHACvOK7JaCAN base-4.17.2.1
    optparse-applicative-0.18.1.0-AUOg1zQqVBXHiykDTBb1RQ
    random-1.2.1.3-AELLTL3R5f5HMsp0oxLypG
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5.2-GNkjiHoVt5N8yPDCzeLpvg

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.3-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.10.3
visibility:           public
id:                   tasty-quickcheck-0.10.3-KbO3IpvMJjnBUhvJK0TpZk
key:                  tasty-quickcheck-0.10.3-KbO3IpvMJjnBUhvJK0TpZk
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  b12b0ce016c230577a7ca4bd282a8658
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-quickcheck-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.3-KbO3IpvMJjnBUhvJK0TpZk
depends:
    QuickCheck-2.15.0.1-GrDIvYvvzO8Kl5FRvvnfbb base-4.17.2.1
    optparse-applicative-0.18.1.0-F3PWwULHYC6ftxzplao6y
    random-1.2.1.3-KtA2QhJP4QW5VMWBGqhhqi
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5.2-LuORlaNFDij9Zxtd2vz1bQ

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
